<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Bino</name>
    <message>
        <location filename="../src/bino.cpp" line="108"/>
        <source>Media player error: %1</source>
        <translation>Medienwiedergabefehler: %1</translation>
    </message>
</context>
<context>
    <name>CommandInterpreter</name>
    <message>
        <location filename="../src/commandinterpreter.cpp" line="47"/>
        <source>Cannot open %1: %2</source>
        <oldsource>Cannot open %1: %2)</oldsource>
        <translation>Kann %1 nicht öffnen: %2</translation>
    </message>
    <message>
        <location filename="../src/commandinterpreter.cpp" line="91"/>
        <location filename="../src/commandinterpreter.cpp" line="97"/>
        <source>Cannot read command from %1</source>
        <translation>Kann kein Kommando von %1 lesen</translation>
    </message>
    <message>
        <location filename="../src/commandinterpreter.cpp" line="127"/>
        <location filename="../src/commandinterpreter.cpp" line="141"/>
        <location filename="../src/commandinterpreter.cpp" line="143"/>
        <location filename="../src/commandinterpreter.cpp" line="160"/>
        <location filename="../src/commandinterpreter.cpp" line="167"/>
        <location filename="../src/commandinterpreter.cpp" line="176"/>
        <location filename="../src/commandinterpreter.cpp" line="185"/>
        <location filename="../src/commandinterpreter.cpp" line="203"/>
        <location filename="../src/commandinterpreter.cpp" line="227"/>
        <location filename="../src/commandinterpreter.cpp" line="238"/>
        <location filename="../src/commandinterpreter.cpp" line="249"/>
        <location filename="../src/commandinterpreter.cpp" line="261"/>
        <location filename="../src/commandinterpreter.cpp" line="298"/>
        <location filename="../src/commandinterpreter.cpp" line="316"/>
        <location filename="../src/commandinterpreter.cpp" line="335"/>
        <location filename="../src/commandinterpreter.cpp" line="343"/>
        <location filename="../src/commandinterpreter.cpp" line="351"/>
        <location filename="../src/commandinterpreter.cpp" line="358"/>
        <location filename="../src/commandinterpreter.cpp" line="367"/>
        <location filename="../src/commandinterpreter.cpp" line="380"/>
        <location filename="../src/commandinterpreter.cpp" line="390"/>
        <location filename="../src/commandinterpreter.cpp" line="398"/>
        <source>Invalid argument in %1 line %2</source>
        <translation>Ungültiges Argument in %1 Zeile %2</translation>
    </message>
    <message>
        <location filename="../src/commandinterpreter.cpp" line="325"/>
        <source>%1: %2</source>
        <translation>%1: %2</translation>
    </message>
    <message>
        <location filename="../src/commandinterpreter.cpp" line="403"/>
        <source>Invalid command %1 line %2</source>
        <oldsource>Invalid command %1</oldsource>
        <translation>Ungültiges Kommando in %1 Zeile %2</translation>
    </message>
</context>
<context>
    <name>Gui</name>
    <message>
        <location filename="../src/gui.cpp" line="76"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Open file...</source>
        <translation type="vanished">Datei &amp;öffnen...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="81"/>
        <source>Open &amp;URL...</source>
        <translation>&amp;URL öffnen...</translation>
    </message>
    <message>
        <source>Open &amp;Camera...</source>
        <translation type="vanished">&amp;Kamera öffnen...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="88"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="93"/>
        <source>&amp;Tracks</source>
        <translation>&amp;Spuren</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="98"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="99"/>
        <source>&amp;Load...</source>
        <translation>&amp;Laden...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="102"/>
        <source>&amp;Save...</source>
        <translation>&amp;Speichern...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="105"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Editieren...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="109"/>
        <source>&amp;Next</source>
        <translation>&amp;Nächster Eintrag</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="113"/>
        <source>&amp;Previous</source>
        <translation>&amp;Vorheriger Eintrag</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="147"/>
        <source>&amp;3D Modes</source>
        <translation>&amp;3D Modi</translation>
    </message>
    <message>
        <source>360° mode</source>
        <translation type="vanished">360° Modus</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="166"/>
        <source>Input 2D</source>
        <translation>Eingabe 2D</translation>
    </message>
    <message>
        <source>Input top/bottom</source>
        <translation type="vanished">Eingabe oben/unten</translation>
    </message>
    <message>
        <source>Input top/bottom half height</source>
        <translation type="vanished">Eingabe oben/unten halbhoch</translation>
    </message>
    <message>
        <source>Input bottom/top</source>
        <translation type="vanished">Eingabe unten/oben</translation>
    </message>
    <message>
        <source>Input bottom/top half height</source>
        <translation type="vanished">Eingabe unten/oben halbhoch</translation>
    </message>
    <message>
        <source>Input left/right</source>
        <translation type="vanished">Eingabe links/rechts</translation>
    </message>
    <message>
        <source>Input left/right half width</source>
        <translation type="vanished">Eingabe links/rechts halbbreit</translation>
    </message>
    <message>
        <source>Input right/left</source>
        <translation type="vanished">Eingabe rechts/links</translation>
    </message>
    <message>
        <source>Input right/left half width</source>
        <translation type="vanished">Eingabe rechts/links halbbreit</translation>
    </message>
    <message>
        <source>Input alternating left/right</source>
        <translation type="vanished">Eingabe abwechselnd links/rechts</translation>
    </message>
    <message>
        <source>Input alternating right/left</source>
        <translation type="vanished">Eingabe abwechselnd rechts/links</translation>
    </message>
    <message>
        <source>Output left</source>
        <translation type="vanished">Ausgabe links</translation>
    </message>
    <message>
        <source>Output right</source>
        <translation type="vanished">Ausgabe rechts</translation>
    </message>
    <message>
        <source>Output OpenGL Stereo</source>
        <translation type="vanished">Ausgabe OpenGL Stereo</translation>
    </message>
    <message>
        <source>Output alternating</source>
        <translation type="vanished">Ausgabe abwechselnd</translation>
    </message>
    <message>
        <source>Output red/cyan high quality</source>
        <translation type="vanished">Ausgabe rot/cyan hohe Qualität</translation>
    </message>
    <message>
        <source>Output red/cyan full color</source>
        <translation type="vanished">Ausgabe rot/cyan vollfarbig</translation>
    </message>
    <message>
        <source>Output red/cyan half color</source>
        <translation type="vanished">Ausgabe rot/cyan halbfarbig</translation>
    </message>
    <message>
        <source>Output red/cyan monochrome</source>
        <translation type="vanished">Ausgabe rot/cyan monochrom</translation>
    </message>
    <message>
        <source>Output green/magenta high quality</source>
        <translation type="vanished">Ausgabe grün/magenta hohe Qualität</translation>
    </message>
    <message>
        <source>Output green/magenta full color</source>
        <translation type="vanished">Ausgabe grün/magenta vollfarbig</translation>
    </message>
    <message>
        <source>Output green/magenta half color</source>
        <translation type="vanished">Ausgabe grün/magenta halbfarbig</translation>
    </message>
    <message>
        <source>Output green/magenta monochrome</source>
        <translation type="vanished">Ausgabe grün/magenta monochrom</translation>
    </message>
    <message>
        <source>Output amber/blue high quality</source>
        <translation type="vanished">Ausgabe bernstein/blau hohe Qualität</translation>
    </message>
    <message>
        <source>Output amber/blue full color</source>
        <translation type="vanished">Ausgabe bernstein/blau vollfarbig</translation>
    </message>
    <message>
        <source>Output amber/blue half color</source>
        <translation type="vanished">Ausgabe bernstein/blau halbfarbig</translation>
    </message>
    <message>
        <source>Output amber/blue monochrome</source>
        <translation type="vanished">Ausgabe bernstein/blau monochrom</translation>
    </message>
    <message>
        <source>Output red/green monochrome</source>
        <translation type="vanished">Ausgabe rot/grün monochrom</translation>
    </message>
    <message>
        <source>Output red/blue monochrome</source>
        <translation type="vanished">Ausgabe rot/blau monochrom</translation>
    </message>
    <message>
        <source>Output even/odd rows</source>
        <translation type="vanished">Ausgabe gerade/ungerade Zeilen</translation>
    </message>
    <message>
        <source>Output even/odd columns</source>
        <translation type="vanished">Ausgabe gerade/ungerade Spalten</translation>
    </message>
    <message>
        <source>Output checkerboard</source>
        <translation type="vanished">Ausgabe Schachbrettmuster</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation type="vanished">Datei &amp;öffnen...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="77"/>
        <source>&amp;Open File(s)...</source>
        <translation>Datei(en) &amp;öffnen...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="84"/>
        <source>Open &amp;Capture Device...</source>
        <translation>&amp;Aufnahmegerät öffnen...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="171"/>
        <source>Input 3D above-below</source>
        <translation>Eingabe 3D übereinander</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="192"/>
        <source>Input 3D side-by-side</source>
        <translation>Eingabe 3D nebeneinander</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="213"/>
        <source>Input 3D alternating</source>
        <translation>Eingabe 3D abwechselnd</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="251"/>
        <source>Output 3D side-by-side</source>
        <translation>Ausgabe 3D nebeneinander</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="272"/>
        <source>Output 3D above-below</source>
        <translation>Ausgabe 3D übereinander</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="293"/>
        <source>Output 3D interleaved</source>
        <translation>Ausgabe 3D verwoben</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="309"/>
        <source>Output 3D anaglyph</source>
        <translation>Ausgabe 3D Anaglyph</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="381"/>
        <source>&amp;Media</source>
        <translation>&amp;Medium</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="382"/>
        <source>Mute audio</source>
        <translation>Ton stumm</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="387"/>
        <source>Increase audio volume</source>
        <translation>Ton lauter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="391"/>
        <source>Decrease audio volume</source>
        <translation>Ton leiser</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="396"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="401"/>
        <source>Seek forward 1 second</source>
        <translation>Vorwärts spulen 1 Sekunde</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="405"/>
        <source>Seek backwards 1 second</source>
        <translation>Rückwärts spulen 1 Sekunde</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="409"/>
        <source>Seek forward 10 seconds</source>
        <translation>Vorwärts spulen 10 Sekunden</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="413"/>
        <source>Seek backwards 10 seconds</source>
        <translation>Rückwärts spulen 10 Sekunden</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="417"/>
        <source>Seek forward 1 minute</source>
        <translation>Vorwärts spulen 1 Minute</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="421"/>
        <source>Seek backwards 1 minute</source>
        <translation>Rückwärts spulen 1 Minute</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="425"/>
        <source>Seek forward 10 minutes</source>
        <translation>Vorwärts spulen 10 Minuten</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="429"/>
        <source>Seek backwards 10 minutes</source>
        <translation>Rückwärts spulen 10 Minuten</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="434"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="435"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="440"/>
        <source>&amp;Swap eyes</source>
        <translation>&amp;Augen tauschen</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="446"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="447"/>
        <source>&amp;About...</source>
        <translation>&amp;Über...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="491"/>
        <location filename="../src/gui.cpp" line="530"/>
        <location filename="../src/gui.cpp" line="687"/>
        <location filename="../src/gui.cpp" line="701"/>
        <location filename="../src/gui.cpp" line="1010"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="503"/>
        <source>Open URL</source>
        <translation>Öffne URL</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="504"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="507"/>
        <location filename="../src/gui.cpp" line="601"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="508"/>
        <location filename="../src/gui.cpp" line="602"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="550"/>
        <source>Open Capture Device</source>
        <translation>Aufnahmegerät öffnen</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="552"/>
        <source>Camera Input:</source>
        <translation>Kamera Eingabe:</translation>
    </message>
    <message>
        <source>Open Camera</source>
        <translation type="vanished">Öffne Kamera</translation>
    </message>
    <message>
        <source>Video Input:</source>
        <translation type="vanished">Video Eingabe:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="554"/>
        <location filename="../src/gui.cpp" line="597"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="558"/>
        <source>Screen Input:</source>
        <translation>Bildschirm Eingabe:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="565"/>
        <source>Window Input:</source>
        <translation>Fenster Eingabe:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="594"/>
        <source>Audio Input:</source>
        <translation>Ton Eingabe:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="596"/>
        <location filename="../src/gui.cpp" line="920"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="683"/>
        <location filename="../src/gui.cpp" line="694"/>
        <source>Playlists (*.m3u)</source>
        <translation>Wiedergabelisten (*.m3u)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="844"/>
        <source>About Bino</source>
        <translation>Über Bino</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="846"/>
        <source>Bino version %1</source>
        <translation>Bino Version %1</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="850"/>
        <source>Copyright (C) %1 Martin Lambers</source>
        <translation>Copyright (C) %1 Martin Lambers</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="852"/>
        <source>This is free software. You may redistribute copies of it under the terms of the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GNU General Public License&lt;/a&gt;. There is NO WARRANTY, to the extent permitted by law.</source>
        <translation>Dieses Programm ist freie Software. Sie dürfen Kopien davon weitergeben gemäß der &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GNU General Public License&lt;/a&gt;.Es gibt KEINERLEI GARANTIE, so weit das Gesetz es erlaubt.</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="872"/>
        <source>Video track %1</source>
        <translation>Videospur %1</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="875"/>
        <location filename="../src/gui.cpp" line="889"/>
        <source> (%1)</source>
        <translation> (%1)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="886"/>
        <source>Audio track %1</source>
        <translation>Tonspur %1</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="900"/>
        <source>No subtitles</source>
        <translation>Keine Untertitel</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="907"/>
        <source>Subtitle track %1</source>
        <translation>Untertitelspur %1</translation>
    </message>
</context>
<context>
    <name>MetaData</name>
    <message>
        <location filename="../src/metadata.cpp" line="51"/>
        <source>Cannot get meta data from %1: %2</source>
        <translation>Kann Metadaten von %1 nicht herausfinden: %2</translation>
    </message>
</context>
<context>
    <name>Mode</name>
    <message>
        <location filename="../src/modes.cpp" line="73"/>
        <source>Input autodetection</source>
        <translation>Eingabe Automatisch</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="76"/>
        <source>Input 2D</source>
        <translation>Eingabe 2D</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="79"/>
        <source>Input top/bottom</source>
        <translation>Eingabe oben/unten</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="82"/>
        <source>Input top/bottom half height</source>
        <translation>Eingabe oben/unten halbhoch</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="85"/>
        <source>Input bottom/top</source>
        <translation>Eingabe unten/oben</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="88"/>
        <source>Input bottom/top half height</source>
        <translation>Eingabe unten/oben halbhoch</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="91"/>
        <source>Input left/right</source>
        <translation>Eingabe links/rechts</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="94"/>
        <source>Input left/right half width</source>
        <translation>Eingabe links/rechts halbbreit</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="97"/>
        <source>Input right/left</source>
        <translation>Eingabe rechts/links</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="100"/>
        <source>Input right/left half width</source>
        <translation>Eingabe rechts/links halbbreit</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="103"/>
        <source>Input alternating left/right</source>
        <translation>Eingabe abwechselnd links/rechts</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="106"/>
        <source>Input alternating right/left</source>
        <translation>Eingabe abwechselnd rechts/links</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="168"/>
        <source>Surround autodetection</source>
        <translation>Surround Automatisch</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="171"/>
        <source>Surround off</source>
        <translation>Surround Aus</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="174"/>
        <source>Surround 180°</source>
        <translation>Surround 180°</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="177"/>
        <source>Surround 360°</source>
        <translation>Surround 360°</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="301"/>
        <source>Output 2D left</source>
        <translation>Ausgabe 2D links</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="304"/>
        <source>Output 2D right</source>
        <translation>Ausgabe 2D rechts</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="307"/>
        <source>Output 3D OpenGL Stereo</source>
        <translation>Ausgabe 3D OpenGL Stereo</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="310"/>
        <source>Output 3D alternating</source>
        <translation>Ausgabe 3D abwechselnd</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="313"/>
        <source>Output HDMI frame pack</source>
        <translation>Ausgabe HDMI Frame Pack</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="316"/>
        <source>Output left/right</source>
        <translation>Ausgabe links/rechts</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="319"/>
        <source>Output left/right half width</source>
        <translation>Ausgabe links/rechts halbbreit</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="322"/>
        <source>Output right/left</source>
        <translation>Ausgabe rechts/links</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="325"/>
        <source>Output right/left half width</source>
        <translation>Ausgabe rechts/links halbbreit</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="328"/>
        <source>Output top/bottom</source>
        <translation>Ausgabe oben/unten</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="331"/>
        <source>Output top/bottom half height</source>
        <translation>Ausgabe oben/unten halbhoch</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="334"/>
        <source>Output bottom/top</source>
        <translation>Ausgabe unten/oben</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="337"/>
        <source>Output bottom/top half height</source>
        <translation>Ausgabe unten/oben halbhoch</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="340"/>
        <source>Output even/odd rows</source>
        <translation>Ausgabe gerade/ungerade Zeilen</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="343"/>
        <source>Output even/odd columns</source>
        <translation>Ausgabe gerade/ungerade Spalten</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="346"/>
        <source>Output checkerboard</source>
        <translation>Ausgabe Schachbrettmuster</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="349"/>
        <source>Output red/cyan high quality</source>
        <translation>Ausgabe rot/cyan hohe Qualität</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="352"/>
        <source>Output red/cyan full color</source>
        <translation>Ausgabe rot/cyan vollfarbig</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="355"/>
        <source>Output red/cyan half color</source>
        <translation>Ausgabe rot/cyan halbfarbig</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="358"/>
        <source>Output red/cyan monochrome</source>
        <translation>Ausgabe rot/cyan monochrom</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="361"/>
        <source>Output green/magenta high quality</source>
        <translation>Ausgabe grün/magenta hohe Qualität</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="364"/>
        <source>Output green/magenta full color</source>
        <translation>Ausgabe grün/magenta vollfarbig</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="367"/>
        <source>Output green/magenta half color</source>
        <translation>Ausgabe grün/magenta halbfarbig</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="370"/>
        <source>Output green/magenta monochrome</source>
        <translation>Ausgabe grün/magenta monochrom</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="373"/>
        <source>Output amber/blue high quality</source>
        <translation>Ausgabe bernstein/blau hohe Qualität</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="376"/>
        <source>Output amber/blue full color</source>
        <translation>Ausgabe bernstein/blau vollfarbig</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="379"/>
        <source>Output amber/blue half color</source>
        <translation>Ausgabe bernstein/blau halbfarbig</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="382"/>
        <source>Output amber/blue monochrome</source>
        <translation>Ausgabe bernstein/blau monochrom</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="385"/>
        <source>Output red/green monochrome</source>
        <translation>Ausgabe rot/grün monochrom</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="388"/>
        <source>Output red/blue monochrome</source>
        <translation>Ausgabe rot/blau monochrom</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="486"/>
        <source>Loop off</source>
        <translation>Wiederholung aus</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="489"/>
        <source>Loop one</source>
        <translation>Wiederholung eins</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="492"/>
        <source>Loop all</source>
        <translation>Wiederholung alle</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="533"/>
        <source>Wait off</source>
        <translation>Warten aus</translation>
    </message>
    <message>
        <location filename="../src/modes.cpp" line="536"/>
        <source>Wait on</source>
        <translation>Warten an</translation>
    </message>
</context>
<context>
    <name>PlaylistEditor</name>
    <message>
        <location filename="../src/playlisteditor.cpp" line="215"/>
        <source>Edit Playlist</source>
        <translation>Editiere Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="222"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="223"/>
        <source>Input Mode</source>
        <translation>Eingabe Modus</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="224"/>
        <source>Surround Mode</source>
        <translation>Surround Modus</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="225"/>
        <source>Video Track</source>
        <translation>Videospur</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="226"/>
        <source>Audio Track</source>
        <translation>Audiospur</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="227"/>
        <source>Subtitle Track</source>
        <translation>Untertitelspur</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="236"/>
        <source>Move up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="239"/>
        <source>Move down</source>
        <translation>Runter</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="242"/>
        <source>Add...</source>
        <translation>Einfügen...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Einfügen</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="245"/>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="248"/>
        <source>Edit...</source>
        <translation>Editieren...</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="251"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="277"/>
        <location filename="../src/playlisteditor.cpp" line="280"/>
        <location filename="../src/playlisteditor.cpp" line="284"/>
        <source>default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="283"/>
        <source>none</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>PlaylistEntryEditor</name>
    <message>
        <location filename="../src/playlisteditor.cpp" line="42"/>
        <source>Edit Playlist Entry</source>
        <translation>Editiere Wiedergabelisteneintrag</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="46"/>
        <location filename="../src/playlisteditor.cpp" line="120"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="51"/>
        <source>Set File...</source>
        <translation>Setze Datei...</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="54"/>
        <source>Set URL...</source>
        <translation>Setze URL...</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="58"/>
        <source>Input Mode:</source>
        <translation>Eingabe Modus:</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="66"/>
        <source>Surround Mode:</source>
        <translation>Surround Modus:</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="74"/>
        <source>Video Track:</source>
        <translation>Videospur:</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="80"/>
        <source>Audio Track:</source>
        <translation>Audiospur:</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="86"/>
        <source>Subtitle Track:</source>
        <translation>Untertitelspur:</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="92"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="119"/>
        <source>Open URL</source>
        <translation>Öffne URL</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="123"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="124"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="167"/>
        <location filename="../src/playlisteditor.cpp" line="171"/>
        <location filename="../src/playlisteditor.cpp" line="198"/>
        <source>default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="175"/>
        <source>none</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../src/playlisteditor.cpp" line="185"/>
        <location filename="../src/playlisteditor.cpp" line="193"/>
        <location filename="../src/playlisteditor.cpp" line="203"/>
        <source> (%1)</source>
        <translation> (%1)</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <location filename="../src/main.cpp" line="123"/>
        <source>3D video player -- see https://bino3d.org</source>
        <translation>3D Videoplayer -- siehe https://bino3d.org</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="124"/>
        <source>Media to play.</source>
        <translation>Medium zum Abspielen.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="128"/>
        <source>Set log level (%1).</source>
        <translation>Setze Logstufe (%1).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="131"/>
        <source>Set log file.</source>
        <translation>Setze Logdatei.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="136"/>
        <source>Use OpenGL ES instead of Desktop OpenGL.</source>
        <translation>Nutze OpenGL ES statt Desktop OpenGL.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="138"/>
        <source>Use OpenGL quad-buffered stereo in GUI mode.</source>
        <translation>Nutze OpenGL Stereo in der Benutzeroberfläche.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="140"/>
        <source>Start in VR mode instead of GUI mode.</source>
        <translation>Starte im VR Modus statt mit der Benutzerobefläche.</translation>
    </message>
    <message>
        <source>Set VR screen geometry, either as a comma-separated list of nine values representing three 3D coordinates that define a planar screen (bottom left, bottom right, top left) or as a name of an OBJ file that contains the screen geometry with texture coordinates.</source>
        <translation type="vanished">Setze die VR Bildschirmgeometrie, entweder als Liste aus neun mit Kommas abgegrenzten Werten die drei 3D Koordinaten repräsentieren welche einen flachen Bildschirm definieren (unten links, unten rechts, oben links) oder als Name einer OBJ Datei die die Bildschirmgeometrie und Texturkoordinaten enthält.</translation>
    </message>
    <message>
        <source>Capture video/audio input from camera and microphone.</source>
        <oldsource>Capture audio/video input from camera and microphone.</oldsource>
        <translation type="vanished">Nehme Bild und Ton von Kamera und Mikrofon auf.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="150"/>
        <source>List audio outputs.</source>
        <translation>Liste die Tonausgabegeräte.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="152"/>
        <source>List audio inputs.</source>
        <translation>Liste die Toneingabegeräte.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="154"/>
        <source>List video inputs.</source>
        <translation>Liste die Bildeingabegeräte.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="160"/>
        <source>Choose audio output via its index.</source>
        <translation>Wähle eine Tonausgabe mit ihrem Index.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="163"/>
        <source>Choose audio input via its index. Can be empty.</source>
        <translation>Wähle eine Toneingabe mit ihrem Index. Kann leer sein.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="166"/>
        <source>Choose video input via its index.</source>
        <translation>Wähle eine Bildeingabe mit ihrem Index.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="177"/>
        <source>Set preferred audio track language (en, de, fr, ...).</source>
        <translation>Setze bevorzugte Tonspursprache (en, de, fr, ...).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="180"/>
        <source>Set preferred subtitle track language (en, de, fr, ...). Can be empty.</source>
        <translation>Setze bevorzugte Untertitelsprache (en, de, fr, ...). Kann leer sein.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="175"/>
        <source>List all video, audio and subtitle tracks in the media.</source>
        <translation>Liste alle Bild-, Ton- und Untertitelspuren im Medium.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="183"/>
        <source>Choose video track via its index.</source>
        <translation>Wähle eine Bildspur mit ihrem Index.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="185"/>
        <source>Choose audio track via its index.</source>
        <translation>Wähle eine Tonspur mit ihrem Index.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="187"/>
        <source>Choose subtitle track via its index. Can be empty.</source>
        <translation>Wähle eine Untertitelspur mit ihrem Index. Kann leer sein.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="219"/>
        <source>Swap left/right eye.</source>
        <translation>Tausche linkes/rechtes Auge.</translation>
    </message>
    <message>
        <source>swap-eyes</source>
        <translation type="vanished">Tausche Augen.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="221"/>
        <source>Start in fullscreen mode.</source>
        <oldsource>fullscreen</oldsource>
        <translation>Starte im Vollbildmodus.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="199"/>
        <source>Set input mode (%1).</source>
        <translation>Setze Eingabemodus (%1).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="205"/>
        <source>Set output mode (%1).</source>
        <translation>Setze Ausgabemodus (%1).</translation>
    </message>
    <message>
        <source>Set 360° mode (%1).</source>
        <translation type="vanished">Setze 360° Modus (%1).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="134"/>
        <source>Read commands from a script file.</source>
        <translation>Lese Kommandos aus einer Skriptdatei.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="142"/>
        <source>Set VR screen geometry, either as the special values &apos;united&apos; or &apos;intersected&apos;, or as a comma-separated list of nine values representing three 3D coordinates that define a planar screen (bottom left, bottom right, top left), or as a an aspect ratio followed by the name of an OBJ file that contains the screen geometry with texture coordinates (example: &apos;16:9,myscreen.obj&apos;).</source>
        <translation>Setze die VR Bildschirmgeometrie, entweder als spezielle Werte &apos;united&apos; oder &apos;intersected&apos;, oder als Liste aus neun mit Kommas abgegrenzten Werten die drei 3D Koordinaten repräsentieren welche einen flachen Bildschirm definieren (unten links, unten rechts, oben links), oder als Seitenverhätlnis gefolgt vom Namen einer OBJ Datei die die Bildschirmgeometrie und Texturkoordinaten enthält (Beispiel: &apos;16:9,meinschirm.obj&apos;).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="148"/>
        <source>Capture audio/video input from microphone and camera/screen/window.</source>
        <translation>Hole Audio/Video von Mikrofon und Kamera/Bildschirm/Fenster.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="156"/>
        <source>List screen inputs.</source>
        <translation>Liste die Bildschirm-Eingabegeräte.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="158"/>
        <source>List window inputs.</source>
        <translation>Liste die Fenster-Eingabegeräte.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="169"/>
        <source>Choose screen input via its index.</source>
        <translation>Wähle eine Bildschirmeingabe mit ihrem Index.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="172"/>
        <source>Choose window input via its index.</source>
        <translation>Wähle eine Fenstereingabe mit ihrem Index.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="190"/>
        <source>Load playlist.</source>
        <translation>Lade Wiedergabeliste.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="193"/>
        <source>Set loop mode (%1).</source>
        <translation>Setze Wiederholungsmodus (%1).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="196"/>
        <source>Set wait mode (%1).</source>
        <translation>Setze Wartemodus</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="216"/>
        <source>Set surround mode (%1).</source>
        <translation>Setze Surroundmodus (%1).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="241"/>
        <location filename="../src/main.cpp" line="260"/>
        <location filename="../src/main.cpp" line="269"/>
        <location filename="../src/main.cpp" line="278"/>
        <location filename="../src/main.cpp" line="372"/>
        <location filename="../src/main.cpp" line="388"/>
        <location filename="../src/main.cpp" line="400"/>
        <location filename="../src/main.cpp" line="412"/>
        <location filename="../src/main.cpp" line="416"/>
        <location filename="../src/main.cpp" line="428"/>
        <location filename="../src/main.cpp" line="432"/>
        <location filename="../src/main.cpp" line="443"/>
        <location filename="../src/main.cpp" line="455"/>
        <location filename="../src/main.cpp" line="467"/>
        <location filename="../src/main.cpp" line="476"/>
        <location filename="../src/main.cpp" line="490"/>
        <location filename="../src/main.cpp" line="500"/>
        <location filename="../src/main.cpp" line="513"/>
        <location filename="../src/main.cpp" line="629"/>
        <location filename="../src/main.cpp" line="636"/>
        <location filename="../src/commandinterpreter.cpp" line="155"/>
        <source>Invalid argument for option %1</source>
        <translation>Ungültiges Argument für Option %1</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="249"/>
        <source>VR mode unavailable - recompile Bino with QVR support!</source>
        <translation>VR Modus nicht verfügbar - rekompiliere Bino mit QVR Unterstützung!</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="300"/>
        <source>No audio outputs available.</source>
        <translation>Keine Tonausgaben verfügbar.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="303"/>
        <source>Audio output %1: %2</source>
        <translation>Tonausgabe %1: %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="310"/>
        <source>No audio inputs available.</source>
        <translation>Keine Toneingaben verfügbar.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="313"/>
        <source>Audio input %1: %2</source>
        <translation>Toneingabe %1: %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="320"/>
        <source>No video inputs available.</source>
        <translation>Keine Bildeingaben verfügbar.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="323"/>
        <source>Video input %1: %2</source>
        <translation>Bildeingabe %1: %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="331"/>
        <location filename="../src/main.cpp" line="337"/>
        <source>No screen inputs available.</source>
        <translation>Keine Bildschirmeingabegeräte vorhanden.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="334"/>
        <source>Screen input %1: %2</source>
        <translation>Bildschirmeingabe %1: %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="345"/>
        <location filename="../src/main.cpp" line="351"/>
        <source>No window inputs available.</source>
        <translation>Keine Fenstereingabegeräte vorhanden.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="348"/>
        <source>Window input %1: %2</source>
        <translation>Fenstereingabe %1: %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="525"/>
        <source>File does not exist: %1</source>
        <translation>Datei existiert nicht: %1</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="538"/>
        <source>%1: %2</source>
        <translation>%1: %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="548"/>
        <source>Cannot capture and play URL at the same time.</source>
        <translation>Kann nicht gleichzeitig aufnehmen und URL wiedergeben.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="566"/>
        <source>video</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="567"/>
        <source>audio</source>
        <translation>Ton</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="568"/>
        <source>subtitle</source>
        <translation>Untertitel</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="572"/>
        <source>no %1 tracks</source>
        <translation>Keine %1spuren</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="575"/>
        <source>%1 track %2</source>
        <translation>%1spur %2</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="738"/>
        <source>Cannot initialize QVR manager</source>
        <translation>Kann QVR Manager nicht initialisieren</translation>
    </message>
</context>
<context>
    <name>Screen</name>
    <message>
        <location filename="../src/screen.cpp" line="102"/>
        <source>Loading screen from %1</source>
        <translation>Lade Bildschirm aus %1</translation>
    </message>
    <message>
        <location filename="../src/screen.cpp" line="111"/>
        <source>Warning: %1</source>
        <oldsource>warning: %1</oldsource>
        <translation>Warnung: %1</translation>
    </message>
    <message>
        <location filename="../src/screen.cpp" line="117"/>
        <source>Error: %1</source>
        <oldsource>error: %1</oldsource>
        <translation>Fehler: %1</translation>
    </message>
    <message>
        <location filename="../src/screen.cpp" line="119"/>
        <source>Unknown error</source>
        <oldsource>unknown error</oldsource>
        <translation>Unbekannter Fehler</translation>
    </message>
</context>
<context>
    <name>VideoFrame</name>
    <message>
        <location filename="../src/videoframe.cpp" line="107"/>
        <source>Pixel format %1 is not hardware accelerated!</source>
        <translation>Pixelformat %1 ist nicht hardwarebeschleunigt!</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/widget.cpp" line="91"/>
        <location filename="../src/widget.cpp" line="92"/>
        <source>Insufficient OpenGL capabilities.</source>
        <oldsource>Insufficient OpenGL capabilities</oldsource>
        <translation>Unzureichende OpenGL Fähigkeiten.</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="92"/>
        <location filename="../src/widget.cpp" line="97"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="96"/>
        <location filename="../src/widget.cpp" line="97"/>
        <source>OpenGL stereo mode is not available on this system.</source>
        <oldsource>OpenGL stereo mode is not available on this system</oldsource>
        <translation>OpenGL Stereo Modus ist nicht verfügbar auf diesem System.</translation>
    </message>
</context>
</TS>
